==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_hac.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=hac
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// F
	'form_pet_adresse_site' => 'آدرس سايت تان', # MODIF
	'form_pet_aucune_signature' => '...هيچ امضائى با اين كد مطابقت نميكند  ', # MODIF
	'form_pet_confirmation' => ':خواهشمند است امضاء تان را تأئيد كنيد',
	'form_pet_deja_signe' => '.شما قبلأ اين متن را امضاء كرده ايد',
	'form_pet_envoi_mail_confirmation' => 'که‌میو ته‌ر دڵنیایی که‌رۆ چه‌ په‌یامیڤی که‌ پێکیانیان. پێ دڵنیابیه‌ی چه‌ واژووکه‌یت پیویستا سه‌ردانی ئا به‌سته‌رییه‌ چا په‌یامه‌نه‌ که‌ری.', # MODIF
	'form_pet_mail_confirmation' => 'سلام,
 
 شما تقاضاى امضاء يك درخواست راكرده ايد    @titre@.

: شما اطلاعات زير را بما داده ايد:
    
@nom_email@:نام @nom_site@-@url_site@سايت :
مهم  
 براى تأئيد امضاء تان، كافيست كه به آدرس زير متصل شويد ( در غير اين صورت درخواستتان رد 
خواهد شد
    @url@

از شركتتان متشكريم
 ',
	'form_pet_message_commentaire' => 'يك پيام ، يك تفسير ؟', # MODIF
	'form_pet_nom_site2' => 'نام سايتتان<b>      ', # MODIF
	'form_pet_probleme_liens' => 'خواهشمند است پیامتان را با حذف پیوند هایپرتکت دریافت کنید.',
	'form_pet_probleme_technique' => 'نقص فنى، امضاء ها موقتأ لغو شدند',
	'form_pet_signature_validee' => 'امضاء تان تأئيد شد. متشكريم !',
	'form_pet_site_deja_enregistre' => 'اين سايت قبلأ ثبت شده',
	'form_pet_url_invalide' => 'كه مشخص كرده ايد معتبر نميباشد URL ',
	'form_pet_votre_email' => 'آدرس ايميل تان',
	'form_pet_votre_nom' => 'نام يا نام مستعارتان', # MODIF
	'form_pet_votre_site' => 'اگر داراى سايتى هستيد، ميتوانيد آنرا در زير ذكر كنيد',

	// I
	'info_signature_supprimee' => 'امضا حذف شده',
	'info_signature_supprimee_erreur' => 'اشتباه: این کد حذفی به هیچ امضائی مربوط نیست' # MODIF
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_hac.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=hac
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_activer_petition' => 'چالاککەردەی قەواڵەی',
	'bouton_radio_pas_petition' => 'هیچ قەۋاڵیـۋ نییا',
	'bouton_radio_petition_activee' => 'قەۋاڵە چالاك کریان',
	'bouton_radio_supprimer_petition' => 'قەۋاڵەکەی بسەڕۆ',

	// F
	'form_pet_adresse_site' => 'آدرس سايت تان', # MODIF
	'form_pet_aucune_signature' => '...هيچ امضائى با اين كد مطابقت نميكند  ', # MODIF
	'form_pet_confirmation' => ':خواهشمند است امضاء تان را تأئيد كنيد',
	'form_pet_deja_signe' => '.شما قبلأ اين متن را امضاء كرده ايد',
	'form_pet_envoi_mail_confirmation' => 'که‌میو ته‌ر دڵنیایی که‌رۆ چه‌ په‌یامیڤی که‌ پێکیانیان. پێ دڵنیابیه‌ی چه‌ واژووکه‌یت پیویستا سه‌ردانی ئا به‌سته‌رییه‌ چا په‌یامه‌نه‌ که‌ری.', # MODIF
	'form_pet_mail_confirmation' => 'سلام,
 
 شما تقاضاى امضاء يك درخواست راكرده ايد    @titre@.

: شما اطلاعات زير را بما داده ايد:
    
@nom_email@:نام @nom_site@-@url_site@سايت :
مهم  
 براى تأئيد امضاء تان، كافيست كه به آدرس زير متصل شويد ( در غير اين صورت درخواستتان رد 
خواهد شد
    @url@

از شركتتان متشكريم
 ',
	'form_pet_message_commentaire' => 'يك پيام ، يك تفسير ؟', # MODIF
	'form_pet_nom_site2' => 'نام سايتتان<b>      ', # MODIF
	'form_pet_probleme_liens' => 'خواهشمند است پیامتان را با حذف پیوند هایپرتکت دریافت کنید.',
	'form_pet_probleme_technique' => 'نقص فنى، امضاء ها موقتأ لغو شدند',
	'form_pet_signature_validee' => 'امضاء تان تأئيد شد. متشكريم !',
	'form_pet_site_deja_enregistre' => 'اين سايت قبلأ ثبت شده',
	'form_pet_url_invalide' => 'كه مشخص كرده ايد معتبر نميباشد URL ',
	'form_pet_votre_email' => 'آدرس ايميل تان',
	'form_pet_votre_nom' => 'نام يا نام مستعارتان', # MODIF
	'form_pet_votre_site' => 'اگر داراى سايتى هستيد، ميتوانيد آنرا در زير ذكر كنيد',

	// I
	'info_signature_supprimee' => 'امضا حذف شده',
	'info_signature_supprimee_erreur' => 'اشتباه: این کد حذفی به هیچ امضائی مربوط نیست' # MODIF
);

?>
